@@ -23,8 +23,8 @@ from fedmsg.meta.base import BaseProcessor
 class AnnounceProcessor(BaseProcessor):
     __name__ = "announce"
     __description__ = "Official Fedora Announcements"
-    __link__ = "http://fedoraproject.org/"
-    __docs__ = "http://fedoraproject.org/"
+    __link__ = "https://fedoraproject.org/"
+    __docs__ = "https://fedoraproject.org/"
     __obj__ = "Announcements"
 
     def subtitle(self, msg, **config):
@@ -34,4 +34,7 @@ class AnnounceProcessor(BaseProcessor):
         return msg['msg']['link']
 
     def usernames(self, msg, **config):
-        return set([msg['username']])
+        users = set()
+        if 'username' in msg:
+            users.update(set([msg['username']]))
+        return users
